@@ -209,8 +209,19 @@ class TcSoaBasics:
 
     @classmethod
     def set_object_load_policy(cls, bo_name: str, properties: List[str]):
-        rest_backend: RestBackend = TcSoaConfig.backend
-        rest_backend.set_object_load_policy(bo_name, properties)
+        TcSoaConfig.backend.set_object_load_policy(bo_name, properties)
+
+    @classmethod
+    def add_object_load_policy(cls, bo_name: str, properties: List[str]):
+        TcSoaConfig.backend.add_object_load_policy(bo_name, properties)
+
+    @classmethod
+    def clear_object_load_policy(cls, bo_name: str):
+        TcSoaConfig.backend.clear_object_load_policy(bo_name)
+
+    @classmethod
+    def clear_all_object_load_policies(cls):
+        TcSoaConfig.backend.clear_all_object_load_policies()
 
     @classmethod
     def get_cached_obj(cls, uid: str):
