@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import Fnd0Client, BusinessObject, Fnd0ClientScope, Fnd0AbstractCommand, Fnd0UIConfigCollectionRel
-from tcsoa.gen.AWS2._2016_12.UiConfig import ClientInput, CommandCollectionInfo, ScopeInput
+from tcsoa.gen.BusinessObjects import BusinessObject, Fnd0AbstractCommand, Fnd0Client, Fnd0UIConfigCollectionRel, Fnd0ClientScope
+from tcsoa.gen.AWS2._2016_12.UiConfig import ScopeInput, ClientInput, CommandCollectionInfo
 from tcsoa.gen.Internal.AWS2._2016_03.UiConfig import CommandContextInfo
 from typing import Dict, List
 from tcsoa.gen.Server import ServiceData
