@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.gen.Bom._2010_09.StructureManagement import TraversedObjectsInput, ObjectCoverageResponse, ObjectCoverageInput, TraversedObjectsResponse
+from tcsoa.gen.Bom._2010_09.StructureManagement import TraversedObjectsResponse, ObjectCoverageInput, TraversedObjectsInput, ObjectCoverageResponse
 from tcsoa.utils import TcService
 
 
