@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BusinessObject, Awp0FullTextSavedSearch
+from tcsoa.gen.BusinessObjects import Awp0FullTextSavedSearch, BusinessObject
 from enum import Enum
 from typing import Dict, List
 from tcsoa.gen.Server import ServiceData
