@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.gen.BusinessObjects import WorkspaceObject, TC_Project
+from tcsoa.gen.BusinessObjects import TC_Project, WorkspaceObject
 from tcsoa.utils import TcBaseObj
 from dataclasses import dataclass
 
