@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.gen.UiConfig._2014_11.UiConfig import ColumnConfig, ScopeInput
+from tcsoa.gen.UiConfig._2014_11.UiConfig import ScopeInput, ColumnConfig
 from typing import List
 from tcsoa.gen.Server import ServiceData
 from tcsoa.utils import TcBaseObj
