@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import BusinessObject
-from tcsoa.gen.Internal.ChangeManagement._2015_03.ChangeManagement import ConnectChangeNoticeToContextInElem, UpdateChangeNoticeRelationsIn, PreviousEffectivity, CreateOrUpdatePreviousEffResp, UpdateChangeNoticeRelationsResp, ConnectChangeNoticeToContextResp
+from tcsoa.gen.Internal.ChangeManagement._2015_03.ChangeManagement import CreateOrUpdatePreviousEffResp, ConnectChangeNoticeToContextResp, UpdateChangeNoticeRelationsResp, UpdateChangeNoticeRelationsIn, ConnectChangeNoticeToContextInElem, PreviousEffectivity
 from typing import List
 from tcsoa.gen.Server import ServiceData
 from tcsoa.utils import TcService
