@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.DebugMonitor._2011_06.DebugMonitor import OperationalHealthData, ValidMetrics, MetricMetaData, MetricAttributes, AlertEventData, MetricConfigMap
-from tcsoa.gen.Internal.DebugMonitor._2011_06.DebugLogging import LoggerLevel, SQLLogInfoResponse, TAOLogLevelResponse, CheckingLevelResponse, ReturnStatus, LoggerLevelResponse, ModuleStatus, ModuleStatusResponse, SQLLogInfo
+from tcsoa.gen.Internal.DebugMonitor._2011_06.DebugMonitor import AlertEventData, MetricMetaData, MetricConfigMap, MetricAttributes, OperationalHealthData, ValidMetrics
+from tcsoa.gen.Internal.DebugMonitor._2011_06.DebugLogging import TAOLogLevelResponse, LoggerLevel, ModuleStatus, SQLLogInfo, ReturnStatus, SQLLogInfoResponse, ModuleStatusResponse, LoggerLevelResponse, CheckingLevelResponse
 from typing import List
 from tcsoa.gen.Internal.DebugMonitor._2011_06.PerformanceMonitor import PerformanceInfoResponse
 from tcsoa.gen.Server import ServiceData
