@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.Mmv._2012_09.SpatialStructureManagement import AcquireSpatialHierarchyResponse, ReleaseSpatialHierarchyIn, GetNodeBBoxResponse, GetNodeBBoxIn, SearchScope, SpatialHierCellInfo, GetSpatialCellsReadTicketsResponse, IsSpatialHierarchyLatestResponse, CreateMmvCursorResponse, AcquireSpatialHierarchyIn, IsSpatialHierarchyIn
+from tcsoa.gen.Internal.Mmv._2012_09.SpatialStructureManagement import GetSpatialCellsReadTicketsResponse, AcquireSpatialHierarchyResponse, SearchScope, SpatialHierCellInfo, GetNodeBBoxIn, AcquireSpatialHierarchyIn, GetNodeBBoxResponse, IsSpatialHierarchyIn, IsSpatialHierarchyLatestResponse, CreateMmvCursorResponse, ReleaseSpatialHierarchyIn
 from tcsoa.gen.BusinessObjects import BusinessObject
 from typing import List
 from tcsoa.gen.Server import ServiceData
