@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from typing import List
-from tcsoa.gen.Internal.UiConfig._2014_11.UiConfig import ResetUIConfigResponse, ResetUIConfigInput
+from tcsoa.gen.Internal.UiConfig._2014_11.UiConfig import ResetUIConfigInput, ResetUIConfigResponse
 from tcsoa.utils import TcService
 
 
