@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import BusinessObject, EPMTask
-from tcsoa.gen.Internal.Workflow._2013_05.Workflow import SoaEPMAction, SoaEPMSupportingValues
+from tcsoa.gen.Internal.Workflow._2013_05.Workflow import SoaEPMSupportingValues, SoaEPMAction
 from tcsoa.utils import TcService
 
 
