@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.gen.Translation._2007_06.TranslationManagement import CreateTranslationRequestArgs, CreateTranslationRequestResponse
+from tcsoa.gen.Translation._2007_06.TranslationManagement import CreateTranslationRequestResponse, CreateTranslationRequestArgs
 from typing import List
 from tcsoa.utils import TcService
 
