@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import Fnd0AbstractCommand, Fnd0ClientScope, Fnd0Client, Fnd0CommandCollection
+from tcsoa.gen.BusinessObjects import Fnd0Client, Fnd0AbstractCommand, Fnd0CommandCollection, Fnd0ClientScope
 from typing import List
 from tcsoa.gen.Server import ServiceData
 from tcsoa.utils import TcBaseObj
