@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BusinessObject, ConfigurationContext, VisStructureContext, BOMLine
+from tcsoa.gen.BusinessObjects import VisStructureContext, ConfigurationContext, BusinessObject, BOMLine
 from typing import List
 from tcsoa.gen.Server import ServiceData
 from tcsoa.utils import TcBaseObj
